==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/igr-shape-filter-record-event-args.js <==
import { IgrShapefileRecord } from "./igr-shapefile-record";
import { ShapeFilterRecordEventArgs as ShapeFilterRecordEventArgs_internal } from "./ShapeFilterRecordEventArgs";
import { ensureBool } from "./componentUtil";
var IgrShapeFilterRecordEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrShapeFilterRecordEventArgs() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    IgrShapeFilterRecordEventArgs.prototype.createImplementation = function () {
        return new ShapeFilterRecordEventArgs_internal();
    };
    Object.defineProperty(IgrShapeFilterRecordEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrShapeFilterRecordEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrShapeFilterRecordEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    };
    Object.defineProperty(IgrShapeFilterRecordEventArgs.prototype, "record", {
        get: function () {
            if (this.i.a == null) {
                return null;
            }
            if (!this.i.a.externalObject) {
                var e = new IgrShapefileRecord();
                e._implementation = this.i.a;
                this.i.a.externalObject = e;
            }
            return this.i.a.externalObject;
        },
        set: function (v) {
            v == null ? this.i.a = null : this.i.a = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrShapeFilterRecordEventArgs.prototype, "shouldInclude", {
        get: function () {
            return this.i.b;
        },
        set: function (v) {
            this.i.b = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    return IgrShapeFilterRecordEventArgs;
}());
export { IgrShapeFilterRecordEventArgs };

==> igniteui-react-core-18.1.0.tgz: package/esm5/lib/igr-shape-filter-record-event-args.js <==
import { IgrShapefileRecord } from "./igr-shapefile-record";
import { ShapeFilterRecordEventArgs as ShapeFilterRecordEventArgs_internal } from "./ShapeFilterRecordEventArgs";
import { ensureBool } from "./componentUtil";
var IgrShapeFilterRecordEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrShapeFilterRecordEventArgs() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    IgrShapeFilterRecordEventArgs.prototype.createImplementation = function () {
        return new ShapeFilterRecordEventArgs_internal();
    };
    Object.defineProperty(IgrShapeFilterRecordEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrShapeFilterRecordEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrShapeFilterRecordEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    };
    Object.defineProperty(IgrShapeFilterRecordEventArgs.prototype, "record", {
        get: function () {
            var r = this.i.a;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = new IgrShapefileRecord();
                if (e.i.setNativeElement) {
                    e.i.setNativeElement(r);
                }
                else {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            v == null ? this.i.a = null : this.i.a = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrShapeFilterRecordEventArgs.prototype, "shouldInclude", {
        get: function () {
            return this.i.b;
        },
        set: function (v) {
            this.i.b = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    return IgrShapeFilterRecordEventArgs;
}());
export { IgrShapeFilterRecordEventArgs };
